ContractValidationError

Enum ContractValidationError 

pub enum ContractValidationError {
    EmptySchemaRef,
    DuplicatePortContract {
        node_id: NodeId,
        port_id: PortId,
    },
    UnknownWorkflowNode {
        node_id: NodeId,
    },
    UnknownWorkflowPort {
        node_id: NodeId,
        port_id: PortId,
        direction: PortDirection,
    },
    PortDirectionMismatch {
        node_id: NodeId,
        port_id: PortId,
        workflow: PortDirection,
        contract: PortDirection,
    },
    MissingCapabilityDescriptor {
        node_id: NodeId,
    },
    SchemaMismatch {
        edge_index: usize,
        source_node_id: NodeId,
        source_port_id: PortId,
        target_node_id: NodeId,
        target_port_id: PortId,
    },
    Capability {
        error: CapabilityValidationError,
    },
}
Validation error for contract metadata.

Variants



EmptySchemaRef

A schema reference was empty or whitespace-only.



DuplicatePortContract

A node contract duplicated the same port identifier.

Fields

node_id: NodeId

Node whose contract is invalid.

port_id: PortId

Duplicated port identifier.



UnknownWorkflowNode

A contract referenced a workflow node that does not exist.

Fields

node_id: NodeId

Missing node identifier.



UnknownWorkflowPort

A contract referenced a port that does not exist on the workflow node.

Fields

node_id: NodeId

Node identifier.

port_id: PortId

Port identifier.

direction: PortDirection

Direction declared by the contract.



PortDirectionMismatch

A contract declared a port with a different direction than the workflow.

Fields

node_id: NodeId

Node identifier.

port_id: PortId

Port identifier.

workflow: PortDirection

Direction declared by the workflow.

contract: PortDirection

Direction declared by the contract.



MissingCapabilityDescriptor

A contract referenced a node with no matching capability descriptor.

Fields

node_id: NodeId

Node identifier.



SchemaMismatch

A contract declared a schema mismatch on a workflow edge.

Fields

edge_index: usize

Zero-based edge index.

source_node_id: NodeId

Source node identifier.

source_port_id: PortId

Source port identifier.

target_node_id: NodeId

Target node identifier.

target_port_id: PortId

Target port identifier.



Capability

Capability validation failed.

Fields

error: CapabilityValidationError

Underlying capability validation error.